var express = require("express");
const connection = require("../../../config/database");
var Validator = require("Validator");
var router = express.Router();
var middleware = require("../../../middleware/validator");
const userModel = require("./user_model");
var multer = require("multer");
var path = require("path");
var { request } = require("http");

//------------------------------------------------------------------ Darshboard -----------------------------------------------------------------
// ========================= Total Contact ==============================

router.post("/totalCount", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.totalcount(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============================ Total Contacts====================================
router.post("/contactListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contacts(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================ Total Followup====================================
router.post("/followupListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_id: "required",
    };
    var message = {
      required: req.language.required,
    };
    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.followups(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================ Total Meetings ====================================
router.post("/meetingListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_id: "required",
    };
    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.meetings(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============================ Total Reconnects ==================================
router.post("/reconnectListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.reconnects(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//------------------------------------------------------------------------------
// ---------------- All notes add
router.post("/addNotes", function (req, res) {
  //console.log("contact",req.body);
  middleware.decryption(req.body, function (request) {
    //console.log("contact id",request);
    var rules = {
      label_id: "required",
      contact_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//------------------------------------------------------------------------------
//========================== Add Followup Notes ================================
router.post("/addFollowupNote", function (req, res) {
  //console.log("contact",req.body);
  middleware.decryption(req.body, function (request) {
    //console.log("contact id",request);
    var rules = {
      contact_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addFollowupNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========================== Delete Followup ===================================
router.post("/deleteFollowup", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteFollowup(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//======================= Add Meeting Notes ====================================
router.post("/addMeetingNote", function (req, res) {
  middleware.decryption(req.body, function (request) {
    console.log("contact", request);

    var rules = {
      contact_id: "required",
      notes: "required",
      file: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addMeetingNotes(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//======================= Delete Meeting =======================================
router.post("/deleteMeeting", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteMeeting(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});
//======================= Filter Dashboard Data =======================================
router.post("/filterData", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      type: "required",
      label: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.filerData(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});
//====================== Add New Contact Type =================================
router.post("/addNewType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      name: "required",
      color: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addNewType(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});
//====================== Rename Contact Type ==================================
router.post("/renameType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      id: "required",
      name: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.renameType(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});
//====================== Delete Contact Type ==================================
router.post("/deleteType", function (req, res) {
  middleware.decryption(req.body, function (request) {
    // console.log(request);
    var rules = {
      id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.deleteType(request, function (code, message, data) {
        middleware.send_response(req, res, code, message, data);
      });
    }
  });
});

//===================== filter level wise ====================================
router.post("/filteLevel", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      level: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.filteLevel(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//==================== Filter Contact =======================================
router.post("/filteContacts", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.filteContacts(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//=================== Add Contact ==========================================
router.post("/addContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      firstname: "required",
      lastname: "required",
      email: "required",
      country_code: "required",
      phone_number: "required",
      type: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.addContact(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=================== View Contact Details==========================================
router.post("/viewContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewContactDetails(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//================== Update Contact Details =============================
router.post("/updateContact", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      contact_id: "required",
      firstname: "required",
      lastname: "required",
      email: "required",
      country_code: "required",
      phone_number: "required",
      type: "required",
      compnay_name: "",
      alternate_email: "",
      additional_phone_number: "",
      profile_image: "",
      hashtags: "",
      address: "",
      contact_method: "",
      timeaine_id: "",
      language_id: "",
      level: "",
      last_update: "",
      social_media_id: "",
      social_media_link: "",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewContactDetails(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//================== Notification Listing ===============================
router.post("/notificationListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.notificationListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================= User Listing ========================================
router.post("/userListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.userListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================= Language Listing ====================================
router.post("/languageListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.languageListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================= Social Media Listing ================================
router.post("/socialMediaListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.socialMediaListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================ Time Zone ============================================
router.post("/timeZoneListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.timeZoneListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//================ Recent/Hight Frequent / Low Frequent / Reconnect Contact ======
router.post("/contactsFiltering", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      filter_no: "required",
    };

    var message = {
      required: req.language.required,
    };
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactsFiltering(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Team Listing =========================================
router.post("/teamListing", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.teamListing(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============== Team Member Listing =================================
router.post("/teamMembers", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.teamMembers(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//============== Teammates Listing / Team Goal ========================
router.post("/teamGoal", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;
    userModel.teamGoal(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============== Create New Team ======================================
router.post("/createTeam", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      member_id: "required",
      team_name: "required",
      team_profile: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;
    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.creatTeam(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============== Join Team ===========================================
router.post("/joinTeam", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.joinTeam(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=========== leave Team ==============================================
router.post("/leaveTeam", function (req, res) {
  middleware.decryption(req.body, function (request) {
    //  console.log(request);

    var rules = {
      team_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    request.user_id = req.user_id;

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.leaveTeam(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//=========== log history =============================================
router.post("/logHistory", function (req, res) {
  middleware.decryption(req.body, function (request) {
    request.user_id = req.user_id;

    userModel.logHistory(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//========== all Bloglisting ===========================================
router.post("/allBloglisting", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allBloglisting(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//========== View Blog ================================================
router.post("/viewBlog", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      blog_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewBlog(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});
//============= all Chatavirsity ======================================
router.post("/allChatavirsity", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allChatavirsity(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//============= View Chatavirsity =====================================
router.post("/viewChatavirsity", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      chatavirsity_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewChatavirsity(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//============= All Faq's ============================================
router.post("/allFaqs", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allFaqs(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//=========== Search Faq ============================================
router.post("/viewFaq", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      search: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.viewFaq(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========== All Ambassabor ========================================
router.get("/allAmbassabor", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allAmbassabor(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//========= Apply Ambassabor =======================================
router.post("/applyAmbassabor", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      program_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.applyAmbassabor(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========== All Subcription ========================================
router.get("/allSubcription", function (req, res) {
  middleware.decryption(req.body, function (request) {
    userModel.allSubcription(request, function (code, message, data) {
      middleware.send_response(request, res, code, message, data);
    });
  });
});

//========== Buy Subcription =======================================
router.post("/buySubcription", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      subcription_id: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.buySubcription(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

//========== Contact Us ============================================
router.post("/contactUs", function (req, res) {
  middleware.decryption(req.body, function (request) {
    var rules = {
      fullname: "required",
      phone_number: "required",
      description: "required",
    };

    var message = {
      required: req.language.required,
    };

    if (middleware.checkValidationRules(res, request, rules, message)) {
      userModel.contactUs(request, function (code, message, data) {
        middleware.send_response(request, res, code, message, data);
      });
    }
  });
});

module.exports = router;
